/*******************************************************************************
 *	BdsTestDeleteData.cc	Deletes all test data
 *				T.Barnaby,	BEAM Ltd,	2009-11-19
 *******************************************************************************
 *
 * This program delete all test data for the "TT" network.
 */
#include <iostream>
#include <iomanip>
#include <stdio.h>
#include <stdlib.h>
#include <getopt.h>
#include <errno.h>
#include <BdsD.h>
#include <BdsC.h>
#include <BFile.h>
#include <BdsLib.h>
#include <sys/stat.h>

using namespace std;
using namespace Bds;

class Config {
public:
				Config();
	int			verbose;
};

Config::Config(){
	verbose = 0;
}

BError testDeleteData(AdminAccess& bds, Config& config){
	BError				err;
	Selection			sel;
	BList<DataFileInfo>		dataFiles;
	BIter				i;

	sel.startTime.setFirst();
	sel.endTime.setLast();
	sel.channels.append(SelectionChannel("TT", "TS.*"));

	// Delete DataFiles
	if(err = bds.dataFileGetList(sel, dataFiles))
		return err;

	for(dataFiles.start(i); !dataFiles.isEnd(i); dataFiles.next(i)){
		if(config.verbose)
			printf("Deleting data file: %s\n", dataFiles[i].url.retStr());
		if(err = bds.dataFileDelete(dataFiles[i].id)){
			printf("Warning: %s\n", err.getString().retStr());
			err.clear();
		}
	}

	return err;
}



void usage(void) {
	cerr << "Usage:\bdsTestDeleteData [options]\n";
	cerr << " -help              - Help on command line parameters\n";
	cerr << " -host <hostname>   - BDS Server host name\n";
	cerr << " -user <user:password> - user id and password\n";
	cerr << " -verbose           - verbose\n";
}

static struct option options[] = {
		{ "?",			0, NULL, 0 },
		{ "h",			0, NULL, 0 },
		{ "help",		0, NULL, 0 },
		{ "host",		1, NULL, 0 },
		{ "user",		1, NULL, 0 },
		{ "verbose",		0, NULL, 0 },
		{ 0,0,0,0 }
};

int main(int argc, char** argv){
	BError			err;
	int			optIndex = 0;
	int			c;
	BString			s;
	AdminAccess		bds;
	BString			hostName;
	BString			user = "testAdmin";
	BString			password = "beam00";
	Config			config;
	
	// Set stdout to line buffering
	setlinebuf(stdout);

	hostName = getenv("BDS_HOST");
	if(hostName == "")
		hostName = "localhost";
		
	while((c = getopt_long_only(argc, argv, "", options, &optIndex)) == 0){
		s = options[optIndex].name;
		if(s == "help" || s == "h" || s == "?"){
			usage();
			return 1;
		}
		else if(s == "host"){
			hostName = optarg;
		}
		else if(s == "user"){
			s = optarg;
			user = s.pullToken(":");
			password = s;
		}
		else if(s == "verbose"){
			config.verbose = 1;
		}
		else {
			usage();
			return 1;
		}
	}
	
	if((argc - optind) != 0){
		usage();
		return 1;
	}

	// Open BDS access
	err = bds.connectService(BString("//") + hostName + "/bdsAdminAccess");

	// Connect to service
	if(!err)
		err = bds.connect(user, password);

	if(!err){
		err = testDeleteData(bds, config);
	}

	if(err)
		cerr << "Error: " << err.getString() << "\n";

	return err.getErrorNo();
}
